package mandelbrot;

import java.awt.Color;

/**
 * A color map with 256 shades of gray ordered from black to white.
 * 
 * @author ahoefer
 *
 */
public class GrayColorMap implements ColorMap {

	private static final int STEPS = 256;
	private Color[] colors;
	
	/**
	 * Standard constructor.
	 */
	public GrayColorMap() {
		colors = new Color[STEPS];
		for (int i = 0; i < STEPS; i++) {
			colors[i] = new Color(i, i, i);
		}
	}
	
	/**
	 * Returns a <code>Color</code> for a value of the Mandelbrot.
	 * 
	 * @param value
	 *            a value of the Mandelbrot
	 * @return a <code>Color</code>, never null.
	 */
	public Color getColor(int value) {
		return colors[value % colors.length];
	}

}
