package mandelbrot;

import java.awt.Component;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.Toolkit;
import java.net.URL;

import javax.swing.Icon;
import javax.swing.ImageIcon;

/**
 * A utility class for icon (image) loading.
 * 
 * @author ahoefer
 * 
 */
public final class IconUtil {

	private static final String ICON_EXTENSION = ".png";

	private static final String ICON_FOLDER = "/icons/";

	private static final String LARGE_ICON_SIZE = "32";

	private static final String SMALL_ICON_SIZE = "16";

	private static final Icon EMPTY = new EmptyIcon();

	private IconUtil() {
	}

	/**
	 * Loads an 16 x 16 Pixel image.
	 * 
	 * @param imageKey May not be null.
	 * @return The image identified by the given key.
	 */
	public static Image getSmallImage(String imageKey) {
		return getImage(imageKey + SMALL_ICON_SIZE);
	}

	/**
	 * Loads an 16 x 16 Pixel icon.
	 * 
	 * @param iconKey May not be null.
	 * @return The icon identified by the given key.
	 */
	public static Icon getSmallIcon(String iconKey) {
		return getIcon(iconKey + SMALL_ICON_SIZE);
	}

	/**
	 * Loads an 32 x 32 Pixel image.
	 * 
	 * @param iconKey May not be null.
	 * @return The icon identified by the given key.
	 */
	public static Icon getLargeIcon(String iconKey) {
		return getIcon(iconKey + LARGE_ICON_SIZE);
	}

	/**
	 * Returns an 16 x 16 Pixel placeholder icon.
	 * @return An empty icon.
	 */
	public static Icon getEmptyIcon() {
		return EMPTY;
	}
	
	private static Image getImage(String imageKey) {
		URL url = IconUtil.class.getResource(ICON_FOLDER + imageKey
				+ ICON_EXTENSION);
		return Toolkit.getDefaultToolkit().getImage(url);
	}

	private static Icon getIcon(String iconKey) {
		return new ImageIcon(getImage(iconKey));
	}
	
	private static class EmptyIcon implements Icon {

		public int getIconHeight() {
			return 16;
		}

		public int getIconWidth() {
			return 16;
		}

		public void paintIcon(Component c, Graphics g, int x, int y) {
			// do nothing
		}
	}
}